import pytest
from mm_std import get_dotenv, hr
from typer.testing import CliRunner


@pytest.fixture()
def mnemonic() -> str:
    return "hub blur cliff taste afraid master game milk nest change blame code"


@pytest.fixture
def passphrase() -> str:
    return "my-secret"


@pytest.fixture()
def mainnet_bip44_address_0() -> str:
    return "1Men3kiujJH7H5NXyKpFtWWtni1cTfSk48"


@pytest.fixture
def binance_address() -> str:
    return "34xp4vRoCGJym3xR7yCVPFHoCNxv4Twseo"


@pytest.fixture
def proxies() -> list[str]:
    proxies_url = get_dotenv("PROXIES_URL")
    if proxies_url:
        res = hr(proxies_url)
        try:
            return res.json["proxies"]
        except KeyError:
            pass
    return []


@pytest.fixture
def cli_runner() -> CliRunner:
    return CliRunner()



import importlib.metadata
import sys
from pathlib import Path

from mm_std import BaseConfig
from rich import print_json


def get_version() -> str:
    return importlib.metadata.version("mm-btc")


def read_config[T: BaseConfig](config_type: type[T], config_path: Path) -> T:
    res = config_type.read_config(config_path)
    if res.is_ok():
        return res.unwrap()

    print_json(res.err)
    sys.exit(1)



from pathlib import Path

from bit import PrivateKey, PrivateKeyTestnet
from mm_std import BaseConfig, print_console

from mm_btc.cli.cli_utils import read_config
from mm_btc.wallet import is_testnet_address


class Config(BaseConfig):
    class Output(BaseConfig):
        address: str
        amount: int

    from_address: str
    private: str
    outputs: list[Output]


def run(config_path: Path) -> None:
    config = read_config(Config, config_path)
    testnet = is_testnet_address(config.from_address)
    key = PrivateKeyTestnet(config.private) if testnet else PrivateKey(config.private)

    outputs = [(o.address, o.amount, "satoshi") for o in config.outputs]

    tx = key.create_transaction(outputs)
    print_console(tx)
